.subckt PCIe_Rx_typ 1 2 3 6 7 8
* simple Rx, only cap and termination
rp 2 3 50
rn 8 3 50
cp 2 3 1p
cn 8 3 1p
.ends PCIe_Rx_typ

.subckt PCIe_Rx_min 1 2 3 6 7 8
* simple Rx, only cap and termination
rp 2 3 40
rn 8 3 40
cp 2 3 0.5p
cn 8 3 0.5p
.ends PCIe_Rx_min

.subckt PCIe_Rx_max 1 2 3 6 7 8
* simple Rx, only cap and termination
rp 2 3 60
rn 8 3 60
cp 2 3 1.5p
cn 8 3 1.5p
.ends PCIe_Rx_max

.subckt PCIe_Tx_typ nvdd outp ngnd in en  pcl  gcl  outn  BUFF=BUFF ibis_file=ibis_models.inc 
+ bitp=400p

*  Some parameters are derived for use in the MacroModel.
* eqdb for pre-empahsis is set here as -3.5
.param adj='-3.5*0.58'
.param cf1='1.0 - (10.0 ^ (adj/20.0))'

*  Some voltage sources are defined to drive the MacroModel. This uses an E element,
*  which is a VCVS, or voltage controlled voltage source.
*
*  N side input voltage to differential buffer
einn inn ngnd v='1 - v(in, ngnd)'

*  The node_param statement tells tlsim to save this waveform for SigWave display.
*  Using the special syntax below, tlsim automatically increments a unique name suffix.
*   .node_param in name=(name(outp) stim) print
* 
*  This is a 2 tap diff driver. You can tell this from the fact that there are
*  2 cf parameters for coefficients and 2 inv parameters for current direction.
*
*  P side driver subcircuit call
xp nvdd outp ngnd in en txpre_2 BUFF=BUFF ibis_file=ibis_file bitp=bitp cf1=cf1

*  N side driver subcircuit call
xn nvdd outn ngnd inn en txpre_2 BUFF=BUFF ibis_file=ibis_file bitp=bitp cf1=cf1

*  Here is the main single-ended driver subcircuit, called txpre_2.
.subckt txpre_2 nvdd out ngnd in en bitp=400p cf1=0.1 

*  Internal termination resistor and pad capacitance elements.
r nvdd out 50
c out ngnd 1p

*  Here are the subcircuit calls for the tap inputs, using subcircuit delayin.
xin1 in1 in ngnd delayin inv=1 del='bitp'

*  Here are the calls for the tx subcircuits, which contain the taps.
xtx0 nvdd out ngnd in en tx scale=1.2
xtx1 nvdd out ngnd in1 en tx scale='1.2 * cf1'

*  This is the subcircuit definition for tx, used for the taps.
.subckt tx nvdd out ngnd in en scale=1.2
bdrvr nvdd out ngnd in en Model=BUFF File=ibis_file c_compX=0  VIScale_pulldown='scale'  VIScale_groundclamp=0
.ends tx

*  The delayin subcircuit drives the inputs to the tx subcircuit.
.subckt delayin in1 in ngnd inv=0 del=0
einp in2 ngnd v='inv * (1 - v(in,ngnd)) + (1-inv) * v(in,ngnd)'
ein1 in1 ngnd pwl in2 ngnd delay=del
datapoints vv
0 0
1 1
end vv
.ends delayin

.ends txpre_2

.ends PCIe_Tx_typ

.subckt PCIe_Tx_min nvdd outp ngnd in en  pcl  gcl  outn  BUFF=BUFF ibis_file=ibis_models.inc 
+ bitp=400p

*  Some parameters are derived for use in the MacroModel.
.param adj='-3.8*0.58'
.param cf1='1.0 - (10.0 ^ (adj/20.0))'

*  Some voltage sources are defined to drive the MacroModel. This uses an E element,
*  which is a VCVS, or voltage controlled voltage source.
*
*  N side input voltage to differential buffer
einn inn ngnd v='1 - v(in, ngnd)'

*  The node_param statement tells tlsim to save this waveform for SigWave display.
*  Using the special syntax below, tlsim automatically increments a unique name suffix.
*   .node_param in name=(name(outp) stim) print
* 
*  This is a 2 tap diff driver. You can tell this from the fact that there are
*  2 cf parameters for coefficients and 2 inv parameters for current direction.
*
*  P side driver subcircuit call
xp nvdd outp ngnd in en txpre_2 BUFF=BUFF ibis_file=ibis_file bitp=bitp cf1=cf1

*  N side driver subcircuit call
xn nvdd outn ngnd inn en txpre_2 BUFF=BUFF ibis_file=ibis_file bitp=bitp cf1=cf1

*  Here is the main single-ended driver subcircuit, called txpre_2.
.subckt txpre_2 nvdd out ngnd in en bitp=400p cf1=0.1 

*  Internal termination resistor and pad capacitance elements.
r nvdd out 40
c out ngnd 1p

*  Here are the subcircuit calls for the tap inputs, using subcircuit delayin.
xin1 in1 in ngnd delayin inv=1 del='bitp'

*  Here are the calls for the tx subcircuits, which contain the taps.
xtx0 nvdd out ngnd in en tx scale=1.4
xtx1 nvdd out ngnd in1 en tx scale='1.4 * cf1'

*  This is the subcircuit definition for tx, used for the taps.
.subckt tx nvdd out ngnd in en scale=1.4
bdrvr nvdd out ngnd in en Model=BUFF File=ibis_file c_compX=0  VIScale_pulldown='scale'  VIScale_groundclamp=0
.ends tx

*  The delayin subcircuit drives the inputs to the tx subcircuit.
.subckt delayin in1 in ngnd inv=0 del=0
einp in2 ngnd v='inv * (1 - v(in,ngnd)) + (1-inv) * v(in,ngnd)'
ein1 in1 ngnd pwl in2 ngnd delay=del
datapoints vv
0 0
1 1
end vv
.ends delayin

.ends txpre_2

.ends PCIe_Tx_min

.subckt PCIe_Tx_max nvdd outp ngnd in en  pcl  gcl  outn  BUFF=BUFF ibis_file=ibis_models.inc 
+ bitp=400p

*  Some parameters are derived for use in the MacroModel.
.param adj='-3.2*0.58'
.param cf1='1.0 - (10.0 ^ (adj/20.0))'

*  Some voltage sources are defined to drive the MacroModel. This uses an E element,
*  which is a VCVS, or voltage controlled voltage source.
*
*  N side input voltage to differential buffer
einn inn ngnd v='1 - v(in, ngnd)'

*  The node_param statement tells tlsim to save this waveform for SigWave display.
*  Using the special syntax below, tlsim automatically increments a unique name suffix.
*   .node_param in name=(name(outp) stim) print
* 
*  This is a 2 tap diff driver. You can tell this from the fact that there are
*  2 cf parameters for coefficients and 2 inv parameters for current direction.
*
*  P side driver subcircuit call
xp nvdd outp ngnd in en txpre_2 BUFF=BUFF ibis_file=ibis_file bitp=bitp cf1=cf1

*  N side driver subcircuit call
xn nvdd outn ngnd inn en txpre_2 BUFF=BUFF ibis_file=ibis_file bitp=bitp cf1=cf1

*  Here is the main single-ended driver subcircuit, called txpre_2.
.subckt txpre_2 nvdd out ngnd in en bitp=400p cf1=0.1 

*  Internal termination resistor and pad capacitance elements.
r nvdd out 60
c out ngnd 1p

*  Here are the subcircuit calls for the tap inputs, using subcircuit delayin.
xin1 in1 in ngnd delayin inv=1 del='bitp'

*  Here are the calls for the tx subcircuits, which contain the taps.
xtx0 nvdd out ngnd in en tx scale=1.0
xtx1 nvdd out ngnd in1 en tx scale='1.0 * cf1'

*  This is the subcircuit definition for tx, used for the taps.
.subckt tx nvdd out ngnd in en scale=1.0
bdrvr nvdd out ngnd in en Model=BUFF File=ibis_file c_compX=0  VIScale_pulldown='scale'  VIScale_groundclamp=0
.ends tx

*  The delayin subcircuit drives the inputs to the tx subcircuit.
.subckt delayin in1 in ngnd inv=0 del=0
einp in2 ngnd v='inv * (1 - v(in,ngnd)) + (1-inv) * v(in,ngnd)'
ein1 in1 ngnd pwl in2 ngnd delay=del
datapoints vv
0 0
1 1
end vv
.ends delayin

.ends txpre_2

.ends PCIe_Tx_max

